@@ -9,7 +9,7 @@ from __future__ import absolute_import
 
 # Set explicit packages
 from .sampler import Sampler as sampler
-from .llh import blr, isotropic_gaussian
+from .llh import blr, isotropic_gaussian, ica
 from ._version import version_number
 
 __author__ = "Charles Matthews"
