@@ -89,13 +89,13 @@ class Sampler:
         Parameters
         ----------
         Nsteps : int
-            the number of steps to produce.
+            the number of steps to run.
         printnum : int, optional
-            if given, prints a  summary of the sampling `printnum` times
+            if given, prints a  summary of the sampling ``printnum`` times
         thin : int, optional
-            thins the trajectory by only including one of each `thin` points
+            thins the trajectory by only including one of each ``thin`` points
         output : list, optional
-            a list of strings giving which arrays should be returned by the function.
+            a list of strings specifying which arrays should be returned by the function.
             The output list can contain
 
             - "pos" : Outputs the trajectory of position
@@ -170,7 +170,7 @@ class Sampler:
 
             if (n + 1) % pf == 0:
                 print(
-                    "Steps:", n + 1, "  Time:", time.time() - stime, "  V:", self.ig.v
+                 "Steps: %5d | Time: %7.3f | V: %+7.3e" % (n+1,time.time() - stime, self.ig.v )
                 )
 
         self.timetaken_value = time.time() - stime
